@@ -50,7 +50,6 @@ def update():
         stats['Nickname'] = ninjas_name
         stats['Link'] = codewars_link
         ninjas.append(stats)
-        #print(stats, '\n')
 
     completed = sorted(ninjas, key = lambda i : float(i['Honor Percentile'][4:][:-1]))
 
@@ -85,7 +84,7 @@ def update():
         kyu_background_color = 'black' if kyu == 1 else 'purple' if kyu == 2 else 'blue' if kyu == 3 or kyu == 4 else 'yellow' if kyu == 5 or kyu == 6 else 'white' if kyu == 7 or kyu == 8 else 'pink'
         kyu_text_color = 'red' if kyu == 1 else 'white' if kyu <= 4 else 'black'
 
-        basic += '|-\n| ' + a['Nickname'] + '[' + codewars_link + ']\n| style="background:' + kyu_background_color + '; color:' + kyu_text_color + '"| ' + a['Rank'][:1] + '\n| ' + a['Honor Percentile'][4:] + '\n| style="background:' + leaderboard_position_background_color + '; color:' + leaderboard_position_text_color + '"| ' + a['Leaderboard Position'][1:] + '\n'
+        basic += '|-\n| ' + a['Nickname'] + '[' + a['Link'] + ']\n| style="background:' + kyu_background_color + '; color:' + kyu_text_color + '"| ' + a['Rank'][:1] + '\n| ' + a['Honor Percentile'][4:] + '\n| style="background:' + leaderboard_position_background_color + '; color:' + leaderboard_position_text_color + '"| ' + a['Leaderboard Position'][1:] + '\n'
 
     basic += '|}'
     print(basic)
